@@ -3,6 +3,7 @@
 from trytond.pool import Pool
 from .payment import *
 from .account import *
+from . import party
 
 
 def register():
@@ -12,10 +13,15 @@ def register():
         Payment,
         MoveLine,
         ProcessPaymentStart,
-        PayLineStart,
+        PayLineAskJournal,
         Configuration,
+        ConfigurationPaymentGroupSequence,
+        Invoice,
+        party.Party,
+        party.PartyPaymentDirectDebit,
         module='account_payment', type_='model')
     Pool.register(
         ProcessPayment,
         PayLine,
+        party.PartyReplace,
         module='account_payment', type_='wizard')
